@@ -566,8 +566,10 @@ void MainWindow::runscript(QString command)
 	QProcess *muoks8 = new QProcess(this);
 	muoks8->start("/sbin/launchcustomizer", systemcommand);
 	muoks8->waitForFinished();
-	sleep(2);
-        system("killall theme-customizer");
+        progress.cancel();
+        QMaemo5InformationBox::information(this, tr("Theme customizations applied!") +  "<br /><br />" + tr("Restart the device to reload all theme elements and make all changes visible."), QMaemo5InformationBox::NoTimeout);
+//	sleep(2);
+//        system("killall theme-customizer");
 
     } else {
 
@@ -822,7 +824,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-60<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-61<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
